@@ -1,7 +1,6 @@
 """Template Tags for DumpDie"""
 
 import inspect
-import pytz
 import re
 import types
 
@@ -25,6 +24,7 @@ from django_dump_die.constants import (
     INCLUDE_MAGIC_METHODS,
     INCLUDE_ATTRIBUTES,
     INCLUDE_FUNCTIONS,
+    PYTZ_PRESENT,
 )
 
 from django_dump_die.utils import (
@@ -46,6 +46,11 @@ from django_dump_die.utils import (
     is_magic,
 )
 
+# Imports that may not be accessible, depending on local python environment setup.
+if PYTZ_PRESENT:
+    import pytz
+
+
 register = template.Library()
 
 
@@ -132,10 +137,13 @@ def dump_object(
             intermediate_value = safe_str(obj)
 
     # Handle if obj is a simple type (Null/None, int, str, bool, and basic number types)
-    # OR if direct parent is a intermediate (excluding pytz timezone objects).
+    # OR if direct parent is an intermediate (excluding pytz timezone objects).
     elif (
         _is_simple_type(obj)
-        or (parent_is_intermediate and not isinstance(obj, pytz.BaseTzInfo))
+        or (
+            (PYTZ_PRESENT and parent_is_intermediate and not isinstance(obj, pytz.BaseTzInfo))
+            or parent_is_intermediate
+        )
     ):
         return _handle_simple_type(obj)
 
@@ -341,7 +349,7 @@ def _is_intermediate_type(obj):
     """Return if the obj is an intermediate type."""
 
     # Special handling for pytz timezone objects.
-    if isinstance(obj, pytz.BaseTzInfo):
+    if PYTZ_PRESENT and isinstance(obj, pytz.BaseTzInfo):
         return True
 
     # Handling for all other objects.
