@@ -6,7 +6,6 @@ to general package usage.
 """
 
 from enum import Enum
-import pytz
 import os
 from datetime import datetime, timedelta
 from decimal import Decimal
@@ -16,7 +15,13 @@ from django.forms import ModelForm
 from django.utils import timezone
 from pathlib import Path, PosixPath, PurePath, WindowsPath
 from types import ModuleType
-from zoneinfo import ZoneInfo
+
+from django_dump_die.constants import PYTZ_PRESENT, ZONEINFO_PRESENT
+
+if PYTZ_PRESENT:
+    import pytz
+if ZONEINFO_PRESENT:
+    from zoneinfo import ZoneInfo
 
 
 BASE_DIR = os.path.dirname(os.path.abspath(__file__))
@@ -398,8 +403,6 @@ def dump_intermediate_types():
 
     dump_datetime_types()
 
-    from pathlib import Path, PosixPath, PurePath, WindowsPath
-
     # Generate variables to dump.
     sample_pure_path = PurePath(Path.cwd())
     try:
@@ -601,8 +604,10 @@ def dump_datetime_types():
     sample_tz_time = timezone.now().time()
     sample_dt_timedelta = timedelta(days=1)
     sample_tz_timedelta = timezone.timedelta(days=2)
-    sample_pytz_timezone = pytz.timezone('UTC')
-    sample_zoneinfo_timezone = ZoneInfo('UTC')
+    if PYTZ_PRESENT:
+        sample_pytz_timezone = pytz.timezone('UTC')
+    if ZONEINFO_PRESENT:
+        sample_zoneinfo_timezone = ZoneInfo('UTC')
 
     # Call dump on all generated variables.
     dump('')
@@ -615,8 +620,10 @@ def dump_datetime_types():
     dump(sample_tz_time)
     dump(sample_dt_timedelta)
     dump(sample_tz_timedelta)
-    dump(sample_pytz_timezone)
-    dump(sample_zoneinfo_timezone)
+    if PYTZ_PRESENT:
+        dump(sample_pytz_timezone)
+    if ZONEINFO_PRESENT:
+        dump(sample_zoneinfo_timezone)
 
 
 def dump_model_types():
